/*
Marvin A. Biscocho
	CS 309
	December 3, 2002
	Professor B.L. Jahr Schaffrath
	Primal Dual Algorithm

Functions:
	InputMatrix - prompts user for matrix and initializes matrix with tracking variables on row 0 and column 0
	DisplayMatrix - displays matrix
	FeasibleMatrix - checks if feasible and gets most negative value if its not feasible
	OptimalMatrix - checks if optimal and gets most negative value if its not optimal
	InterpretMatrix - displays minimal or maximal value at the basic variable variables, also reports if there is no solution
	GetSimplexPivot - searches for most negative in objective function row, and gets the ratio for positive elements in pivot column
	                - determines the lowest ratio (pivot row), determines simplex pivot element
	GetDualSimplexPivot - searches for most negative in right column, and gets the ratio for negative elements in pivot row
	                    - determines the highest ratio (pivot column), determines dual simplex pivot element
	WhichPivot - uses both simplex and dual simplex pivots and calculates which to use for condensed table algorithm
	CondensedTableAlgorithm - Reduces matrix into new matrix, replaced pivot element with reciprocal
	                        - Divides pivot row with pivot element
							- Divides pivot column with -pivot element
							- fills in new matrix

Successfully:
    inputs matrix
	sets up matrix
	tracks variables
	checks if feasible
	checks if optimal
	gets most negative in objective function row
	gets most negative in for right column
	interprets the matrix
	gets simplex pivot     // may run into problems if there is a tie with ratios...if no ratios, it can't check other negatives in that row
	gets dual simplex pivot  // may run into problems if there is a tie with ratios...if no ratios, it can't check other negatives in that column
	knows to use simplex or dual-simplex pivot
	condensed table algorithm
	outputs activity to a file called 'PrimalDualResults.txt' in the 'C:\' directory

Tested (and worked fine...with floating point):
	Simplex:
			max f(x1, x2) = x1 + 2x2
			subject to:   x1 + 3x2 <= 7
						  2x1 + x2 <= 4
						  x1, x2 >= 0

			max f(x1, x2) = 8x1 + 9x2
			subject to:   x1 + 2x2 <= 8
						  2x1 + 3x2 <= 13
						  x1 + x2 <= 6
						  x1, x2 >= 0

			max f(x1, x2, x3) = 2x1 + 3x2 + x3
			subject to:   x1 + 4x2 - 2x3 <= 10
						  0x1 + 3x2 + x3 <= 7
						  2x1 - 3x2 + 4x3 <= 12
						  x1, x2, x3 >= 0
	Dual Simplex:
			min f(x1, x2, x3) = x1 + x2 + x3
			subject to:   3x1 + x2 + x3 >= 1
						  0x1 + 5x2 + 0x3 >= 1
						  3x1 + 0x2 + 5x3 >= 1
						  x1, x2, x3 >= 0			

  			min f(x1, x2, x3) = 3x1 + 8x2 + 5x3
			subject to:   x1 + x2 + x3 >= 7
						  1x1 + 2x2 + 1x3 >= 5
						  -1x1 + 1x2 + 0x3 >= 6
						  x1, x2, x3 >= 0	

	Primal Dual:
  			min f(x1, x2, x3) = 1x1 + 2x2 + 1x3
			subject to:   3x1 + 2x2 + 4x3 <= 26
						  2x1 + 1x2 + 2x3 >= 13
						  2x1 + 5x2 + 3x3 >= 17
						  3x1 + x2 + 2x3 = 16
						  x1, x2, x3 >= 0	

    		max f(x1, x2, x3) = 3x1 + 2x2 - 2x3
			subject to:   4x1 + 3x2 - 2x3 <= 11
						  5x1 - 2x2 + 7x3 >= 2
						  1x1 + 1x2 + 3x3 <= 15				
						  x1, x2, x3 >= 0	
Unsuccessful:
	// no floating point, just fractions
	// keep fractions reduced (no floating point)
	// tried rational class...not working    
*/

// Includes
#include <iostream.h>
#include <iomanip.h>
// #include "rational.h"  // trying not to use floating point
#include <string>
#include <ctype.h>
#include <fstream>
using namespace std;

// Global variables
int NumOfNonBasicVariables;   // number of columns
int NumOfBasicVariables;      // number of rows
int i;						  // row index
int j;						  // column index
int m;						  // interation counter
int coefficient;			  // input placed into matrix
int ecount = 0;				  // count equalities
char error;					  // test if errors
char ProblemType;			  // min(n)/max(x) 
char cont;					  // ask user to continue (y/n)
const MaxMatrixRowSize = 9;   // constant matrix row size
const MaxMatrixColSize = 9;   // constant matrix column size
float A[MaxMatrixRowSize][MaxMatrixColSize];   // set up matrix
int B[MaxMatrixColSize];	  // array for negative values when 'equal' constraint occurs
char ConstraintType[MaxMatrixRowSize];  // array to track the constraint types
char AddNewRow = 'n';               // add new row for equal
char feasible[MaxMatrixRowSize];	// feasible matrix
char optimal[MaxMatrixColSize];		// optimal matrix
float NegRghtCol[MaxMatrixRowSize];	  // negative in right column...use for dual
float MostNegRghtCol = 0;	               // most negative in right column
int IndexMostNegRghtCol;	  // index of the most negative column
float NegBotRow[MaxMatrixColSize];	  // negative in bottom row...use for simplex
float MostNegBotRow = 0;					// most negative in bottom row
int IndexMostNegBotRow;		  // index of the most negative row
char IsFeasible = 'y';					// final character if it is feasible
char IsOptimal = 'y';					// final character if it is optimal
float SimplexRatio[MaxMatrixRowSize];	  // ratios
float SmallestSimplexRatio = 100000;	 // initialy set very high 
int IndexSmallestSimplexRatio;  // row with smallest ratio
float SimplexPivot = 14652;			  //initially set to this, if doesn't change odds are that SimplexPivot was not found
char SimplexError = 'n';				// will be set to 'y' if no pivot found
float DualSimplexRatio[MaxMatrixRowSize];	  // ratios
float GreatestDualSimplexRatio = -100000;	   // initially set very low
int IndexGreatestDualSimplexRatio;  // row with smallest ratio
float DualSimplexPivot = 14652;			  //initially set to this, if doesn't change odds are that DualSimplexPivot was not found
char DualSimplexError = 'n';            // will be set to 'y' if no pivot found
char UseThisPivot;				// Simp or Dual

// prototypes
void InputMatrix();
void DisplayMatrix(int NumOfNonBasicVariables, int NumOfBasicVariables, float A[MaxMatrixRowSize][MaxMatrixColSize]);
void FeasibleMatrix(int NumOfNonBasicVariables, int NumOfBasicVariables, float A[MaxMatrixRowSize][MaxMatrixColSize]);
void OptimalMatrix(int NumOfNonBasicVariables, int NumOfBasicVariables, float A[MaxMatrixRowSize][MaxMatrixColSize]);
void InterpretMatrix(char ProblemType, int SimplexPivot, int DualSimplexPivot, int NumOfNonBasicVariables, int NumOfBasicVariables, float A[MaxMatrixRowSize][MaxMatrixColSize]);
void GetSimplexPivot(char IsOptimal, float MostNegBotRow, int IndexMostNegBotRow, int NumOfNonBasicVariables, int NumOfBasicVariables, float A[MaxMatrixRowSize][MaxMatrixColSize]);
void GetDualSimplexPivot(char IsFeasible, float MostNegRghtCol, int IndexMostNegRghtCol, int NumOfNonBasicVariables, int NumOfBasicVariables, float A[MaxMatrixRowSize][MaxMatrixColSize]);
void WhichPivot(char SimplexError, char DualSimplexError, float MostNegBotRow, int IndexSmallestSimplexRatio, float SmallestSimplexRatio, float MostNegRghtCol, int IndexGreatestDualSimplexRatio, float GreatestDualSimplexRatio, float A[MaxMatrixRowSize][MaxMatrixColSize]);
void CondensedTableAlgorithm(char UseThisPivot, float SimplexPivot, float DualSimplexPivot, int IndexMostNegBotRow, int IndexSmallestSimplexRatio, int IndexMostNegRghtCol, int IndexGreatestDualSimplexRatio, int NumOfNonBasicVariables, int NumOfBasicVariables, float A[MaxMatrixRowSize][MaxMatrixColSize]);
ofstream outfile("c:\\PrimalDualResults.txt");

// main program
int main() {
	outfile << "Marvin Biscocho" << endl;
	outfile << "CS 309" << endl;
	outfile << "Professor B.L. Jahr Schaffrath" << endl;
	outfile << "December 3, 2002" << endl;
	outfile << "Primal Dual Algorithm" << endl;
	outfile << endl << endl;

	InputMatrix();
	DisplayMatrix(NumOfNonBasicVariables ,NumOfBasicVariables, A);
	FeasibleMatrix(NumOfNonBasicVariables ,NumOfBasicVariables, A);
    OptimalMatrix(NumOfNonBasicVariables ,NumOfBasicVariables, A);

	// Get both pivots
	GetSimplexPivot(IsOptimal, MostNegBotRow, IndexMostNegBotRow, NumOfNonBasicVariables ,NumOfBasicVariables, A);
	GetDualSimplexPivot(IsFeasible, MostNegRghtCol, IndexMostNegRghtCol, NumOfNonBasicVariables, NumOfBasicVariables, A);

	// start program
	if (IsFeasible == 'y' && IsOptimal == 'y') {
		// Done.
		cout << endl << endl << endl << "***************************************************" << endl;
		outfile << endl << endl << endl << "***************************************************" << endl;
		cout << "********Already Entered a Optimized Problem!*******" << endl;
		outfile << "********Already Entered a Optimized Problem!*******" << endl;
		cout << "***************************************************" << endl;
		outfile << "***************************************************" << endl;

		InterpretMatrix(ProblemType, SimplexError, DualSimplexError, NumOfNonBasicVariables ,NumOfBasicVariables, A);
	}
	else if (IsFeasible == 'y' && IsOptimal == 'n' && SimplexPivot != 14652) {
		cout << endl << endl << "Using Simplex Method!" << endl;
		outfile << endl << endl << "Using Simplex Method!" << endl;
		//GetSimplexPivot(IsOptimal, MostNegBotRow, IndexMostNegBotRow, NumOfNonBasicVariables ,NumOfBasicVariables, A);
		/*if (SimplexError == 'n') {
			cout << "Simplex Pivot: " << SimplexPivot << endl;
		}	
		else {
			cout << "There is no simplex pivot!" << endl;
		}*/
		while (m<5) {
			DisplayMatrix(NumOfNonBasicVariables ,NumOfBasicVariables, A);
			FeasibleMatrix(NumOfNonBasicVariables ,NumOfBasicVariables, A);
			OptimalMatrix(NumOfNonBasicVariables ,NumOfBasicVariables, A);
			if (IsFeasible == 'y' && IsOptimal == 'y') {
				// Simplified...your done...exit for loop
				cout << endl << endl << endl << "***************************************************" << endl;
				outfile << endl << endl << endl << "***************************************************" << endl;
				cout << "**********Problem Optimized Successfully!**********" << endl;
				outfile << "**********Problem Optimized Successfully!**********" << endl;
				cout << "***************************************************" << endl;
				outfile << "***************************************************" << endl;
				InterpretMatrix(ProblemType, SimplexError, DualSimplexError, NumOfNonBasicVariables ,NumOfBasicVariables, A);
				m = 6;
			}
			else {
				GetSimplexPivot(IsOptimal, MostNegBotRow, IndexMostNegBotRow, NumOfNonBasicVariables ,NumOfBasicVariables, A);
				GetDualSimplexPivot(IsFeasible, MostNegRghtCol, IndexMostNegRghtCol, NumOfNonBasicVariables, NumOfBasicVariables, A);
				UseThisPivot = 'S';
				//WhichPivot(SimplexError, DualSimplexError, MostNegBotRow, IndexSmallestSimplexRatio, SmallestSimplexRatio, MostNegRghtCol, IndexGreatestDualSimplexRatio, GreatestDualSimplexRatio, A);
				CondensedTableAlgorithm(UseThisPivot, SimplexPivot, DualSimplexPivot, IndexMostNegBotRow, IndexSmallestSimplexRatio, IndexMostNegRghtCol, IndexGreatestDualSimplexRatio, NumOfNonBasicVariables, NumOfBasicVariables, A);
				InterpretMatrix(ProblemType, SimplexError, DualSimplexError, NumOfNonBasicVariables ,NumOfBasicVariables, A);
				cout << "Continue. (y/n)?" << endl;
				outfile << "Continue. (y/n)?" << endl;
				cin >> cont;
				outfile << cont << endl;
				if (cont == 'y') {
					
				}
				else if (cont == 'n') {
					main();
				}
				else {
					cout << "Error: Invalid Entry!" << endl;
					outfile << "Error: Invalid Entry!" << endl;
					main();
				}
			}
		}
	}
/*
	GetSimplexPivot(IsOptimal, MostNegBotRow, IndexMostNegBotRow, NumOfNonBasicVariables ,NumOfBasicVariables, A);
	if (SimplexError == 'n') {
		cout << "Simplex Pivot: " << SimplexPivot << endl;
	}	
	else {
		cout << "There is no simplex pivot!" << endl;
	}
*/	
	else if (IsFeasible == 'n' && IsOptimal == 'y' && DualSimplexPivot != 14652) {
		cout << endl << endl << "Using Dual Simplex Method!" << endl;
		outfile << endl << endl << "Using Dual Simplex Method!" << endl;
		//GetDualSimplexPivot(IsFeasible, MostNegRghtCol, IndexMostNegRghtCol, NumOfNonBasicVariables ,NumOfBasicVariables, A);
		/*if (DualSimplexError == 'n') {
			cout << "Dual Simplex Pivot: " << DualSimplexPivot << endl;
		}	
		else {
			cout << "There is no dual simplex pivot!" << endl;
		}*/
		while (m<5) {
			DisplayMatrix(NumOfNonBasicVariables ,NumOfBasicVariables, A);
			FeasibleMatrix(NumOfNonBasicVariables ,NumOfBasicVariables, A);
			OptimalMatrix(NumOfNonBasicVariables ,NumOfBasicVariables, A);
			if (IsFeasible == 'y' && IsOptimal == 'y') {
				// Simplified...your done...exit for loop
				cout << endl << endl << endl << "***************************************************" << endl;
				outfile << endl << endl << endl << "***************************************************" << endl;
				cout << "**********Problem Optimized Successfully!**********" << endl;
				outfile << "**********Problem Optimized Successfully!**********" << endl;
				cout << "***************************************************" << endl;
				outfile << "***************************************************" << endl;
				InterpretMatrix(ProblemType, SimplexError, DualSimplexError, NumOfNonBasicVariables ,NumOfBasicVariables, A);
				m = 6;
			}
			else {
				GetSimplexPivot(IsOptimal, MostNegBotRow, IndexMostNegBotRow, NumOfNonBasicVariables ,NumOfBasicVariables, A);
				GetDualSimplexPivot(IsFeasible, MostNegRghtCol, IndexMostNegRghtCol, NumOfNonBasicVariables, NumOfBasicVariables, A);
				UseThisPivot = 'D';
				//WhichPivot(SimplexError, DualSimplexError, MostNegBotRow, IndexSmallestSimplexRatio, SmallestSimplexRatio, MostNegRghtCol, IndexGreatestDualSimplexRatio, GreatestDualSimplexRatio, A);
				CondensedTableAlgorithm(UseThisPivot, SimplexPivot, DualSimplexPivot, IndexMostNegBotRow, IndexSmallestSimplexRatio, IndexMostNegRghtCol, IndexGreatestDualSimplexRatio, NumOfNonBasicVariables, NumOfBasicVariables, A);
				InterpretMatrix(ProblemType, SimplexError, DualSimplexError, NumOfNonBasicVariables ,NumOfBasicVariables, A);
				cout << "Continue. (y/n)?" << endl;
				outfile << "Continue. (y/n)?" << endl;
				cin >> cont;
				outfile << cont << endl;
				if (cont == 'y') {
					
				}
				else if (cont == 'n') {
					main();
				}
				else {
					cout << "Error: Invalid Entry!" << endl;
					outfile << "Error: Invalid Entry!" << endl;
					main();
				}
			}
		}
	}
/*
	GetDualSimplexPivot(IsFeasible, MostNegRghtCol, IndexMostNegRghtCol, NumOfNonBasicVariables ,NumOfBasicVariables, A);
	if (DualSimplexError == 'n') {
		cout << "Dual Simplex Pivot: " << DualSimplexPivot << endl;
	}	
	else {
		cout << "There is no dual simplex pivot!" << endl;
	}
*/
	else if (IsFeasible == 'n' && IsOptimal == 'n' && DualSimplexPivot != 14652 && SimplexPivot != 14652) {
		// Primal Dual
		cout << endl << endl << "Using Primal Dual Method!" << endl;
		outfile << endl << endl << "Using Primal Dual Method!" << endl;
		// Get Simplex Pivot
	/*	GetSimplexPivot(IsOptimal, MostNegBotRow, IndexMostNegBotRow, NumOfNonBasicVariables ,NumOfBasicVariables, A);
		if (SimplexError == 'n') {
			cout << "Simplex Pivot: " << SimplexPivot << endl;
		}	
		else {
			cout << "There is no simplex pivot!" << endl;
		}*/
		// Get Dual-Simplex Pivot
	/*	GetDualSimplexPivot(IsFeasible, MostNegRghtCol, IndexMostNegRghtCol, NumOfNonBasicVariables ,NumOfBasicVariables, A);
		if (DualSimplexError == 'n') {
			cout << "Dual Simplex Pivot: " << DualSimplexPivot << endl;
		}	
		else {
			cout << "There is no dual simplex pivot!" << endl;
		}*/
		
		while (m<5) {
			DisplayMatrix(NumOfNonBasicVariables ,NumOfBasicVariables, A);
			FeasibleMatrix(NumOfNonBasicVariables ,NumOfBasicVariables, A);
			OptimalMatrix(NumOfNonBasicVariables ,NumOfBasicVariables, A);
			if (IsFeasible == 'y' && IsOptimal == 'y') {
				// Problem Optimized...your done...exit for loop
				cout << endl << endl << endl << "***************************************************" << endl;
				outfile << endl << endl << endl << "***************************************************" << endl;
				cout << "**********Problem Optimized Successfully!**********" << endl;
				outfile << "**********Problem Optimized Successfully!**********" << endl;
				cout << "***************************************************" << endl;
				outfile << "***************************************************" << endl;
				InterpretMatrix(ProblemType, SimplexError, DualSimplexError, NumOfNonBasicVariables ,NumOfBasicVariables, A);
				m = 6;
			}
			else {
				GetSimplexPivot(IsOptimal, MostNegBotRow, IndexMostNegBotRow, NumOfNonBasicVariables ,NumOfBasicVariables, A);
				GetDualSimplexPivot(IsFeasible, MostNegRghtCol, IndexMostNegRghtCol, NumOfNonBasicVariables, NumOfBasicVariables, A);
				//UseThisPivot = 'D';
				WhichPivot(SimplexError, DualSimplexError, MostNegBotRow, IndexSmallestSimplexRatio, SmallestSimplexRatio, MostNegRghtCol, IndexGreatestDualSimplexRatio, GreatestDualSimplexRatio, A);
				CondensedTableAlgorithm(UseThisPivot, SimplexPivot, DualSimplexPivot, IndexMostNegBotRow, IndexSmallestSimplexRatio, IndexMostNegRghtCol, IndexGreatestDualSimplexRatio, NumOfNonBasicVariables, NumOfBasicVariables, A);
				InterpretMatrix(ProblemType, SimplexError, DualSimplexError, NumOfNonBasicVariables ,NumOfBasicVariables, A);
				cout << "Continue. (y/n)?" << endl;
				outfile << "Continue. (y/n)?" << endl;
				cin >> cont;
				outfile << cont << endl;
				if (cont == 'y') {
					
				}
				else if (cont == 'n') {
					main();
				}
				else {
					cout << "Error: Invalid Entry!" << endl;
					outfile << "Error: Invalid Entry!" << endl;
					main();
				}
			}
		}
	}

/*	if (SimplexError == 'n' && DualSimplexError == 'n') {
		// Primal Dual
		WhichPivot(MostNegBotRow, IndexSmallestSimplexRatio, SmallestSimplexRatio, MostNegRghtCol, IndexGreatestDualSimplexRatio, GreatestDualSimplexRatio, A);

	}
	else if (SimplexError == 'n' && DualSimplexError == 'n') {
		// Simplex
		WhichPivot(MostNegBotRow, IndexSmallestSimplexRatio, SmallestSimplexRatio, MostNegRghtCol, IndexGreatestDualSimplexRatio, GreatestDualSimplexRatio, A);

	}

	else if (SimplexError == 'n' && DualSimplexError == 'n') {
		// Dual Simplex
		WhichPivot(MostNegBotRow, IndexSmallestSimplexRatio, SmallestSimplexRatio, MostNegRghtCol, IndexGreatestDualSimplexRatio, GreatestDualSimplexRatio, A);
	}
*/
//	WhichPivot(SimplexError, DualSimplexError, MostNegBotRow, IndexSmallestSimplexRatio, SmallestSimplexRatio, MostNegRghtCol, IndexGreatestDualSimplexRatio, GreatestDualSimplexRatio, A);

//    InterpretMatrix(ProblemType, SimplexError, DualSimplexError, NumOfNonBasicVariables ,NumOfBasicVariables, A);
	//CondensedTableAlgorithm(UseThisPivot, SimplexPivot, DualSimplexPivot, IndexMostNegBotRow, IndexSmallestSimplexRatio, IndexMostNegRghtCol, IndexGreatestDualSimplexRatio, NumOfNonBasicVariables, NumOfBasicVariables, A) {
//	CondensedTableAlgorithm(UseThisPivot, SimplexPivot, DualSimplexPivot, IndexMostNegBotRow, IndexSmallestSimplexRatio, IndexMostNegRghtCol, IndexGreatestDualSimplexRatio, NumOfNonBasicVariables, NumOfBasicVariables, A);
    
//	DisplayMatrix(NumOfNonBasicVariables ,NumOfBasicVariables, A);
	
//	InterpretMatrix(ProblemType, SimplexError, DualSimplexError, NumOfNonBasicVariables ,NumOfBasicVariables, A);


	return 0;
}


// functions
//**********************************************
void InputMatrix() {
	// get matrix dimensions
	// columns

	cout << "How many non-basic variables are involved?" << endl;
	outfile << "How many non-basic variables are involved?" << endl;
	cin >> NumOfNonBasicVariables;
	outfile << NumOfNonBasicVariables << endl;
	if (NumOfNonBasicVariables > MaxMatrixColSize) {
		cout << "Error: Max Size is set at 9" << endl;
		//error = 'y';
		//start over
		main();
	}
	// rows
	cout << "How many basic variables (constraints) are involved?" << endl;
	outfile << "How many basic variables (constraints) are involved?" << endl;
	cin >> NumOfBasicVariables;
	outfile << NumOfBasicVariables << endl;
	if (NumOfBasicVariables > MaxMatrixRowSize) {
		cout << "Error: Max Size is set at 9" << endl;
		outfile << "Error: Max Size is set at 9" << endl;
		//error = 'y';
		//start over
		main();
	}
	
	for (i = 1; i < NumOfBasicVariables + 1; i++) {
		cout << "What kind of constraint is constraint " << i << " ?  (l, g, e)" << endl;
		outfile << "What kind of constraint is constraint " << i << " ?  (l, g, e)" << endl;
		cin >> ConstraintType[i];
		outfile << ConstraintType[i] << endl;
		if (ConstraintType[i] == 'l') {
				//possible simplex
			cout << "Please Enter the Coefficients for Constraint " << i << endl;
			outfile << "Please Enter the Coefficients for Constraint " << i << endl;			
			cout << "for example x1 + x2 = 3....enter 1 1 3" << endl;
			outfile << "for example x1 + x2 = 3....enter 1 1 3" << endl;
			for (j = 1; j < NumOfNonBasicVariables + 2; j++) {
				cin >> coefficient;
				outfile << coefficient << endl;
				A[i][j] = coefficient;
			}
		}
		else if (ConstraintType[i] == 'g') {
			//possible dual simplex
			cout << "Please Enter the Coefficients for Constraint " << i << endl;
			outfile << "Please Enter the Coefficients for Constraint " << i << endl;
			cout << "for example x1 + x2 = 3....enter 1 1 3" << endl;
			outfile << "for example x1 + x2 = 3....enter 1 1 3" << endl;
			for (j = 1; j < NumOfNonBasicVariables + 2; j++) {
				cin >> coefficient;
				outfile << coefficient << endl;
				A[i][j] = -coefficient;
			}
		}
		else if (ConstraintType[i] == 'e') {
			ecount = ecount+1;
			//possible primal dual
			cout << "Please Enter the Coefficients for Constraint " << i << endl;
			outfile << "Please Enter the Coefficients for Constraint " << i << endl;
			cout << "for example x1 + x2 = 3....enter 1 1 3" << endl;
			outfile << "for example x1 + x2 = 3....enter 1 1 3" << endl;
			for (j = 1; j < NumOfNonBasicVariables + 2; j++) {
				cin >> coefficient;
				outfile << coefficient << endl;
				A[i][j] = coefficient;
				A[NumOfBasicVariables+ecount][j] = -coefficient;
				//NumOfBasicVariables = NumOfBasicVariables + 1;
				AddNewRow = 'y';
				//B[j] = -coefficient;
				//	NumOfBasicVariables = NumOfBasicVariables + 1;
				//	for (j = 1; j < NumOfNonBasicVariables + 2; j++) {
				//		A[NumOfBasicVariables][j] = -coefficient;  //B[j];
				//	}
			}
			//A[i+1][j] = A[i][j];
			//A[i+2][j] = -A[i][j];
		}
		else {
			cout << "Error:  not a valid inequality" << endl;
			outfile << "Error:  not a valid inequality" << endl;
			// start over
			main();
		}
	}
    // add new row for equality
	if (AddNewRow == 'y') {
		NumOfBasicVariables = NumOfBasicVariables + ecount;
//		for (j = 1; j < NumOfNonBasicVariables + 2; j++) {
//			A[NumOfBasicVariables][j] = B[j];
//		}
	}	
	cout << "What type of optimal problem is this?  (n = (Min) or x = (Max))" << endl;
	outfile << "What type of optimal problem is this?  (n = (Min) or x = (Max))" << endl;
	cin >> ProblemType;
	outfile << ProblemType << endl;
	if (ProblemType == 'x') {
		// possible simplex
		cout << "What is the objective function? " << endl;
		outfile << "What is the objective function? " << endl;
		cout << " for example:  f(x1, x2, x3) = 2x1 + 3x2 -3x3...enter 2 3 -3 0" << endl;
		outfile << " for example:  f(x1, x2, x3) = 2x1 + 3x2 -3x3...enter 2 3 -3 0" << endl;
				for (j = 1; j < NumOfNonBasicVariables + 2; j++) {
					cin >> coefficient;
					outfile << coefficient << endl;
					A[NumOfBasicVariables+1][j] = -coefficient;
				}	
	}
	else if (ProblemType == 'n') {
		// possible dual simplex
		cout << "What is the objective function? " << endl;
		outfile << "What is the objective function? " << endl;
		cout << " for example:  f(x1, x2, x3) = 2x1 + 3x2 -3x3...enter 2 3 -3 0" << endl;
		outfile << " for example:  f(x1, x2, x3) = 2x1 + 3x2 -3x3...enter 2 3 -3 0" << endl;
				for (j = 1; j < NumOfNonBasicVariables + 2; j++) {
					cin >> coefficient;
					outfile << coefficient << endl;
					A[NumOfBasicVariables+1][j] = coefficient;
				}	
	}
	else {
		cout << "Error: Invalid Entry!" << endl;
		outfile << "Error: Invalid Entry!" << endl;
		main();
	}
	

	// set up tracking variables
	for (j = 0; j <= NumOfNonBasicVariables; j++) {
		A[0][j] = j; 
	}

	for (i = 0; i <= NumOfBasicVariables + 1; i++) {
		A[i][0] = j-1;
		j++;
	}
	A[0][0] = 0;

/*	cout << "What is the objective function? " << endl;
		for (j = 1; j < NumOfNonBasicVariables + 2; j++) {
			cin >> coefficient;
			A[NumOfBasicVariables+1][j] = coefficient;
		}
*/


}
//**********************************************
void DisplayMatrix(int NumOfNonBasicVariables, int NumOfBasicVariables, float A[MaxMatrixRowSize][MaxMatrixColSize]) {
cout << endl << endl << endl << "/*************Displaying Matrix with Tracking Variables****************/" << endl;
outfile << endl << endl << endl << "/*************Displaying Matrix with Tracking Variables****************/" << endl;
	int i;
	for (i = 0; i < NumOfBasicVariables + 2; i++) {
		for (j = 0; j < NumOfNonBasicVariables + 2; j++) {
			cout << A[i][j] << ' ' << ' ' << ' ' << ' ';
			outfile << A[i][j] << ' ' << ' ' << ' ' << ' ';
		}
		cout << endl;
		outfile << endl;
	}
}
//**********************************************
void FeasibleMatrix(int NumOfNonBasicVariables, int NumOfBasicVariables, float A[MaxMatrixRowSize][MaxMatrixColSize]) {
cout << endl << endl << endl << "/*************Checking if Matrix is Feasible****************/" << endl;
outfile << endl << endl << endl << "/*************Checking if Matrix is Feasible****************/" << endl;
	int i;
	int temp = 0;
	feasible[0] = 'y';
	IsFeasible = 'y';
	for (i = 1; i < NumOfBasicVariables + 1; i++) {
		NegRghtCol[i] = 0;
	}
	for (i = 1; i < NumOfBasicVariables + 1; i++) {
		//cout << A[i][NumOfNonBasicVariables + 1] << endl;
		if (A[i][NumOfNonBasicVariables + 1] > 0) {
			feasible[i] = 'y';
		}
		else {
			feasible[i] = 'n';
		}
		//cout << feasible[i] << endl;
		
		if (feasible[i] == feasible[i-1] && feasible[i] == 'y') {
			//IsFeasible = 'y';
		}
		else {
			//IsFeasible = 'n';
			NegRghtCol[i] = A[i][NumOfNonBasicVariables+1];
		}
		// cout << "Negative value in Right Column: " << NegRghtCol[i] << endl; 
	}
		for (i = 1; i < NumOfBasicVariables + 1; i++) {
			if (feasible[i] == 'y') {
				//feasible
			}
			else {
				IsFeasible = 'n';
			}
		}
	
/*	for (i = 0; i < NumOfBasicVariables + 1; i++) {
		cout << A[i][NumOfBasicVariables+1] << ' ';
		feasible[i-1] = 'y';
		if (feasible[i] == feasible[i-1] && feasible[i] == 'y') {
			IsFeasible = 'y';
		}
		else {
			IsFeasible = 'n';
			NegRghtCol[i] = A[i][NumOfBasicVariables+1];
		}
	//	cout << NegRghtCol[i] << ' '; 
	}*/

	temp = MostNegRghtCol;
	MostNegRghtCol = 0;
	for (i = 1; i < NumOfBasicVariables + 1; i++) {
		//cout << NegRghtCol[i] << ' '; 
		if (NegRghtCol[i] < MostNegRghtCol && MostNegRghtCol <= 0) {
			MostNegRghtCol = NegRghtCol[i];
			IndexMostNegRghtCol = i;
		//	cout << "NegRghtCol[i]: " << NegRghtCol[i] << endl;
		//	cout << "MostNegRghtCol: " << MostNegRghtCol << endl;
		//	cout << "IndexMostNegRghtCol: " << IndexMostNegRghtCol << endl;

		}

	}

	for (i = 1; i < NumOfBasicVariables + 1; i++) {
		//if (NegRghtCol[i] < MostNegRghtCol) {
			//MostNegRghtCol = NegRghtCol[i];
			//IndexMostNegRghtCol = i;
//			cout << "NegRghtCol[i]: " << NegRghtCol[i] << endl;
//			cout << "MostNegRghtCol: " << MostNegRghtCol << endl;
//			cout << "IndexMostNegRghtCol: " << IndexMostNegRghtCol << endl;
		//}

	}
		cout << "Feasible Matrix: " << IsFeasible << endl;
		outfile << "Feasible Matrix: " << IsFeasible << endl;
		if (IsFeasible != 'y') {
			cout << "Most Negative in Right Column: " << MostNegRghtCol << endl;
			outfile << "Most Negative in Right Column: " << MostNegRghtCol << endl;
		}
//	MostNegRghtCol = temp;
}

//**********************************************
void OptimalMatrix(int NumOfNonBasicVariables, int NumOfBasicVariables, float A[MaxMatrixRowSize][MaxMatrixColSize]) {
cout << endl << endl << endl << "/*************Checking if Matrix is Optimal****************/" << endl;
outfile << endl << endl << endl << "/*************Checking if Matrix is Optimal****************/" << endl;
	int j;
	int temp = 0;
	IsOptimal = 'y';
	for (j = 1; j < NumOfNonBasicVariables + 1; j++) {
		NegBotRow[j] = 0;
	}
/*	for (j = 0; j < NumOfNonBasicVariables + 1; j++) {
		if (A[NumOfBasicVariables+1][j] > 0) {
			optimal[j] = 'y';
		}
		else {
			optimal[j] = 'n';
		}
	}*/
/*	for (j = 0; j < NumOfNonBasicVariables + 1; j++) {
		if (optimal[j] == optimal[j-1] && optimal[j] == 'y') {
			IsOptimal = 'y';
		}
		else {
			IsOptimal = 'n';
			NegBotRow[j] = A[NumOfNonBasicVariables+1][j];
		}
	}*/
/*	for (j = 1; j < NumOfNonBasicVariables + 1; j++) {
		if (NegBotRow[j] < MostNegBotRow) {
			MostNegBotRow = NegBotRow[j];
		}
	}*/
	optimal[0] = 'y';
	for (j = 1; j < NumOfNonBasicVariables + 1; j++) {
		//cout << A[NumOfBasicVariables + 1][j] << endl;
		if (A[NumOfBasicVariables + 1][j] > 0) {
			optimal[j] = 'y';
		}
		else {
			optimal[j] = 'n';
		}
		//cout << optimal[j] << endl; 
		//cout << "optimal[j] == optimal[j-1]: " << optimal[j] << "==" << optimal[j-1] << "     " << "optimal[j] == \'y\':" << optimal[j] << "== \'y\'"  << endl;	
		if (optimal[j] == optimal[j-1] && optimal[j] == 'y') {
			//IsOptimal = 'y';
		}
		else {
			//IsOptimal = 'n';
			NegBotRow[j] = A[NumOfBasicVariables+1][j];
		}
		//cout << NegRghtCol[i] << endl; 
	}
	
		for (j = 1; j < NumOfNonBasicVariables + 1; j++) {
			if (optimal[j] == 'y') {
				//optimal
			}
			else {
				IsOptimal = 'n';
			}
		}
/*	for (i = 0; i < NumOfBasicVariables + 1; i++) {
		cout << A[i][NumOfBasicVariables+1] << ' ';
		feasible[i-1] = 'y';
		if (feasible[i] == feasible[i-1] && feasible[i] == 'y') {
			IsFeasible = 'y';
		}
		else {
			IsFeasible = 'n';
			NegRghtCol[i] = A[i][NumOfBasicVariables+1];
		}
	//	cout << NegRghtCol[i] << ' '; 
	}*/
	temp = MostNegBotRow;
	MostNegBotRow = 0;

	for (j = 1; j < NumOfNonBasicVariables + 1; j++) {
		//cout << NegRghtCol[i] << ' '; 
		if (NegBotRow[j] < MostNegBotRow && MostNegBotRow <= 0) {
			MostNegBotRow = NegBotRow[j];
			IndexMostNegBotRow = j;
		}
	//	cout << "Index Most Neg Row: " << IndexMostNegBotRow << endl;
	//	cout << "MostNegBotRow: " << MostNegBotRow<< endl;
	}
		cout << "Optimal Matrix: " << IsOptimal << endl;
		outfile << "Optimal Matrix: " << IsOptimal << endl;
		if (IsOptimal != 'y') {
			cout << "Most Negative in Objective Function Row: " << MostNegBotRow << endl;
			outfile << "Most Negative in Objective Function Row: " << MostNegBotRow << endl;
		}
//	MostNegBotRow = temp;
}

//**********************************************
void InterpretMatrix(char ProblemType, int SimplexPivot, int DualSimplexPivot, int NumOfNonBasicVariables, int NumOfBasicVariables, float A[MaxMatrixRowSize][MaxMatrixColSize]) {
cout << endl << endl << endl << "/*************Interpretting Matrix****************/" << endl;
outfile << endl << endl << endl << "/*************Interpretting Matrix****************/" << endl;
	int i;
	int j;
 	if (ProblemType == 'x') {
		cout << "Maximum of " << A[NumOfBasicVariables + 1][NumOfNonBasicVariables + 1] << " at: " << endl;
		outfile << "Maximum of " << A[NumOfBasicVariables + 1][NumOfNonBasicVariables + 1] << " at: " << endl;
		for (i = 1; i < NumOfBasicVariables + 1; i++) {
			cout << "   x" << A[i][0] << " = " << A[i][NumOfNonBasicVariables + 1] << endl;
			outfile << "   x" << A[i][0] << " = " << A[i][NumOfNonBasicVariables + 1] << endl;
		}
	}
	else {
		cout << "Minimum at " << -1*A[NumOfBasicVariables + 1][NumOfNonBasicVariables + 1] << endl;
		outfile << "Minimum at " << -1*A[NumOfBasicVariables + 1][NumOfNonBasicVariables + 1] << endl;
		for (i = 1; i < NumOfBasicVariables + 1; i++) {
			cout << "   x" << A[i][0] << " = " << A[i][NumOfNonBasicVariables + 1] << endl;
			outfile << "   x" << A[i][0] << " = " << A[i][NumOfNonBasicVariables + 1] << endl;
		}	
	}
		cout << endl;
		outfile << endl;
		
		for (j = 1; j < NumOfNonBasicVariables + 1; j++) {
			cout << "   x" << A[0][j] << " = 0" << endl;
			outfile << "   x" << A[0][j] << " = 0" << endl;
		}
//	if (SimplexPivot == 14652 && DualSimplexPivot == 14652) {
//		cout << temp << " at " << A[NumOfBasicVariables + 1][NumOfNonBasicVariables + 1] << endl;
//		for (i = 1; i < NumOfBasicVariables + 1; i++) {
//			cout << " x" << A[i][0] << " = " << A[i][NumOfNonBasicVariables + 1] << endl;
//		}
//	}
//	else {
//		cout << "No Solution, (could not find a pivot)" << endl;
//	}
}

//**********************************************
void GetSimplexPivot(char IsOptimal, float MostNegBotRow, int IndexMostNegBotRow, int NumOfNonBasicVariables, int NumOfBasicVariables, float A[MaxMatrixRowSize][MaxMatrixColSize]) {
cout << endl << endl << endl << "/*************Getting Simplex Pivot****************/" << endl;
outfile << endl << endl << endl << "/*************Getting Simplex Pivot****************/" << endl;
	int i;
	int temp = 0;
	temp = SmallestSimplexRatio;
	SmallestSimplexRatio = 100000;
	if (IsOptimal == 'y') {
		// there are not negative elements for simplex pivots
		SimplexError = 'y';
	}
	else {
		for (i = 1; i < NumOfBasicVariables + 1; i++) {
			//cout << "A[i][IndexMostNegBotRow]: " << A[i][IndexMostNegBotRow] << endl;
			if (A[i][IndexMostNegBotRow] > 0 /*&& A[i][NumOfNonBasicVariables + 1] > 0*/) {
				SimplexRatio[i] = (float)A[i][NumOfNonBasicVariables + 1]/(float)A[i][IndexMostNegBotRow];
				cout << "Simplex Ratios: " << A[i][NumOfNonBasicVariables + 1] << "/" << A[i][IndexMostNegBotRow] << " = " << SimplexRatio[i] << endl;
				outfile << "Simplex Ratios: " << A[i][NumOfNonBasicVariables + 1] << "/" << A[i][IndexMostNegBotRow] << " = " << SimplexRatio[i] << endl;
				if (SimplexRatio[i] < SmallestSimplexRatio /*&& SimplexRatio[i] > 0*/) {
					SmallestSimplexRatio = SimplexRatio[i];
					IndexSmallestSimplexRatio = i;
					SimplexPivot = A[IndexSmallestSimplexRatio][IndexMostNegBotRow];	
			//		cout << "SmallestSimplexRatio: " << SmallestSimplexRatio << endl;
			//		cout << "IndexSmallestSimplexRatio: " << IndexSmallestSimplexRatio << endl;
			//		cout << "IndexMostNegBotRow: " << IndexMostNegBotRow << endl;
			//		cout << "SimplexPivot: " << SimplexPivot << endl;
			//		cout << endl << endl;
				}		
			}
		}
	}
	if (SimplexPivot == 14652) {
		// Default SimplexPivot set at 100000
		// Nothing Changed...no simplex found
		SimplexError = 'y';
	}
		if (SimplexError == 'n') {
			cout << "Simplex Pivot: " << SimplexPivot << endl;
			outfile << "Simplex Pivot: " << SimplexPivot << endl;
		}	
		else {
			cout << "There is no simplex pivot!" << endl;
			outfile << "There is no simplex pivot!" << endl;
		}
}

//**********************************************
void GetDualSimplexPivot(char IsFeasible, float MostNegRghtCol, int IndexMostNegRghtCol, int NumOfNonBasicVariables, int NumOfBasicVariables, float A[MaxMatrixRowSize][MaxMatrixColSize]) {
cout << endl << endl << endl << "/*************Getting Dual Simplex Pivot****************/" << endl;
outfile << endl << endl << endl << "/*************Getting Dual Simplex Pivot****************/" << endl;
	int j;
	int temp = 0;
	temp = GreatestDualSimplexRatio;
	GreatestDualSimplexRatio = -100000;
	if (IsFeasible == 'y') {
		// there are not negative elements for simplex pivots
		DualSimplexError = 'y';
	}
	else {
		for (j = 1; j < NumOfNonBasicVariables + 1; j++) {
			if (A[IndexMostNegRghtCol][j] < 0 /*&& A[NumOfBasicVariables + 1][j] > 0*/) {
				DualSimplexRatio[j] = (float)A[NumOfBasicVariables + 1][j]/(float)A[IndexMostNegRghtCol][j];
				cout << "Dual Simplex Ratios: " << A[NumOfBasicVariables + 1][j] << "/" << A[IndexMostNegRghtCol][j] << " = " << DualSimplexRatio[j] << endl;
				outfile << "Dual Simplex Ratios: " << A[NumOfBasicVariables + 1][j] << "/" << A[IndexMostNegRghtCol][j] << " = " << DualSimplexRatio[j] << endl;
				if (DualSimplexRatio[j] > GreatestDualSimplexRatio && DualSimplexRatio[j] < 0) {
					GreatestDualSimplexRatio = DualSimplexRatio[j];
					IndexGreatestDualSimplexRatio = j;
					DualSimplexPivot = A[IndexMostNegRghtCol][IndexGreatestDualSimplexRatio];			
				}		
			}
		}
	}

	if (DualSimplexPivot == 14652) {
		// Default SimplexPivot set at 100000
		// Nothing Changed...no simplex found
		DualSimplexError = 'y';
	}
		if (DualSimplexError == 'n') {
			cout << "Dual Simplex Pivot: " << DualSimplexPivot << endl;
			outfile << "Dual Simplex Pivot: " << DualSimplexPivot << endl;
		}	
		else {
			cout << "There is no dual simplex pivot!" << endl;
			outfile << "There is no dual simplex pivot!" << endl;
		}
	
	//	cout << "IndexMostNegRghtCol: " << IndexMostNegRghtCol << endl;
	//	cout << "IndexGreatestDualSimplexRatio: " << IndexGreatestDualSimplexRatio << endl;
}

//**********************************************
void WhichPivot(char SimplexError, char DualSimplexError, float MostNegBotRow, int IndexSmallestSimplexRatio, float SmallestSimplexRatio, float MostNegRghtCol, int IndexGreatestDualSimplexRatio, float GreatestDualSimplexRatio, float A[MaxMatrixRowSize][MaxMatrixColSize]) {
cout << endl << endl << endl << "/*************Which Pivot to Use?****************/" << endl;
outfile << endl << endl << endl << "/*************Which Pivot to Use?****************/" << endl;

cout << "MostNegBotRow: " << MostNegBotRow << endl;
outfile << "MostNegBotRow: " << MostNegBotRow << endl;

cout << "MostNegRghtCol: " << MostNegRghtCol << endl;
outfile << "MostNegRghtCol: " << MostNegRghtCol << endl;

float Simp = 0;
float Dual = 0;

if (SimplexError == 'y') {
	MostNegBotRow = 0;
}
if (DualSimplexError == 'y') {
	MostNegRghtCol = 0;
}

Simp = MostNegBotRow*SmallestSimplexRatio;
Dual = MostNegRghtCol*GreatestDualSimplexRatio;

cout << "Calculate Simplex: " << MostNegBotRow << '*' << SmallestSimplexRatio << '=' << Simp << endl;
outfile << "Calculate Simplex: " << MostNegBotRow << '*' << SmallestSimplexRatio << '=' << Simp << endl;
cout << "Calculate Dual: " << MostNegRghtCol << '*' << GreatestDualSimplexRatio << '=' << Dual << endl;
outfile << "Calculate Dual: " << MostNegRghtCol << '*' << GreatestDualSimplexRatio << '=' << Dual << endl;

//cout << "Simplex: " << Simp << endl;
//cout << "Dual Simplex: " << Dual << endl;

	if (Simp < 0) {
		Simp = -Simp;
	}

	if (Dual < 0) {
		Dual = -Dual;
	}

	if (Simp > Dual) {
		cout << "Use Simplex Pivot, it has the largest magnitude of: " << Simp << endl;
		outfile << "Use Simplex Pivot, it has the largest magnitude of: " << Simp << endl;
		UseThisPivot = 'S';
	}
	else {
		cout << "Use Dual Simplex Pivot, it has the largest magnitude of: " << Dual << endl;
		outfile << "Use Dual Simplex Pivot, it has the largest magnitude of: " << Dual << endl;
		UseThisPivot = 'D';
	}

}

//**********************************************
void CondensedTableAlgorithm(char UseThisPivot, float SimplexPivot, float DualSimplexPivot, int IndexMostNegBotRow, int IndexSmallestSimplexRatio, int IndexMostNegRghtCol, int IndexGreatestDualSimplexRatio, int NumOfNonBasicVariables, int NumOfBasicVariables, float A[MaxMatrixRowSize][MaxMatrixColSize]) {
cout << endl << endl << endl << "/*************Condensed Table Algorithm****************/" << endl;
outfile << endl << endl << endl << "/*************Condensed Table Algorithm****************/" << endl;

int i;
int j;
float C[MaxMatrixRowSize][MaxMatrixColSize];
float D[MaxMatrixRowSize][MaxMatrixColSize];
int pivot_row;
int pivot_column;
float pivot_element;
float reciprocal;
float temp;
int col;	

if (UseThisPivot == 'S') {
	// using simplex pivot...know which row and column where pivot is
	pivot_row = IndexSmallestSimplexRatio;
	pivot_column = IndexMostNegBotRow;
	pivot_element = SimplexPivot;
	col = NumOfNonBasicVariables + 2;
}

else {
	// using dual simplex pivot...know which row and column where pivot is
	pivot_row = IndexMostNegRghtCol;
	pivot_column = IndexGreatestDualSimplexRatio;
	pivot_element = DualSimplexPivot;
	col = NumOfNonBasicVariables + 2;
}

//cout << "IndexSmallestSimplexRatio: " << IndexSmallestSimplexRatio << endl;
//cout << "IndexMostNegBotRow: " << IndexMostNegBotRow << endl;
//cout << "SimplexPivot: " << SimplexPivot << endl;

//cout << "IndexGreatestDualSimplexRatio: " << IndexGreatestDualSimplexRatio << endl;
//cout << "IndexMostNegRghtCol: " << IndexMostNegRghtCol << endl;
//cout << "DualSimplexPivot: " << DualSimplexPivot << endl;


//cout << "UseThisPivot: " << UseThisPivot << endl;
cout << "Pivot row: " << pivot_row << endl;
outfile << "Pivot row: " << pivot_row << endl;
cout << "Pivot column: " << pivot_column << endl;
outfile << "Pivot column: " << pivot_column << endl;
cout << "Pivot element: " << pivot_element << endl;
outfile << "Pivot element: " << pivot_element << endl;

cout << endl << endl << endl;
outfile << endl << endl << endl;
	
	// Create C matrix (hold new row and column)
	for (i = 1; i < NumOfBasicVariables + 2; i++) {
		for (j = 1; j < NumOfNonBasicVariables + 2; j++) {
			if (j == pivot_column) {
				C[i][j] = A[i][j]/(-pivot_element);	
			}				
			else if (i == pivot_row) {
				C[i][j] = A[i][j]/(pivot_element);	
			}
			else {
				//C[i][j] = A[i][j] - A[i][pivot_column]*C[pivot_row][j];
				C[i][j] = 0;
			}	
		}
	}
	
	// change pivot element to reciprocal
	reciprocal = 1/((float)pivot_element);
	C[pivot_row][pivot_column] = reciprocal;

/*	
	cout << "A: " << endl;
	for (i = 1; i < NumOfBasicVariables + 2; i++ ) {
		for (j = 1; j < col; j++ ) {
			//if (C[i][j] < 0) {  
				cout << A[i][j] << "    ";	
			//}
			//else {
			//	cout << C[i][j] << "    ";	
			//}		
		}
		cout << endl;
	}
*/	
/*
	cout << endl << endl << endl << endl;
	cout << "C: " << endl;
	for (i = 1; i < NumOfBasicVariables + 2; i++ ) {
		for (j = 1; j < col; j	++ ) {
			if (C[i][j] < 0) {  
				cout << C[i][j] << "    ";	
			}
			else {
				cout << C[i][j] << "    ";	
			}		
		}
		cout << endl;
	}
    
*/
	// create D matrix, which contains the new matrix
	for (i = 1; i < NumOfBasicVariables + 2; i++) {
		for (j = 1; j < col; j++) {
			if (j == pivot_column) {
				//C[i][j] = A[i][j]/(-pivot_element);	
				D[i][j] = C[i][j];
			}				
			else if (i == pivot_row) {
				//C[i][j] = A[i][j]/(pivot_element);	
				D[i][j] = C[i][j];
			}
			else {
				//C[i][j] = 0;
				D[i][j] = A[i][j] - A[i][pivot_column]*C[pivot_row][j];
			}	

		}
	}
/*	
	// Display the New Matrix
	cout << endl << "D: " << endl;
	for (i = 1; i < NumOfBasicVariables + 2; i++ ) {
		for (j = 1; j < col; j	++ ) {
			if (C[i][j] < 0) {  
				cout << D[i][j] << "    ";	
			}
			else {
				cout << D[i][j] << "    ";	
			}		
		}
		cout << endl;
	}
*/	
	// Matrix A may need to be reduced again in the main program
	for (i = 1; i < NumOfBasicVariables + 2; i++ ) {
		for (j = 1; j < col; j	++ ) {
			A[i][j] = D[i][j];	
		}
	}
	
	// keep tracking variables straight
	temp = A[0][pivot_column];
	A[0][pivot_column] = A[pivot_row][0];
	A[pivot_row][0] = temp;

}